package controller

import (
	"electricity_bill_calc/logger"
	"electricity_bill_calc/response"
	"electricity_bill_calc/service"
	"github.com/gofiber/fiber/v2"
	"go.uber.org/zap"
)

var GmLog = logger.Named("Handler", "GM")

func InitializeGmController(router *fiber.App) {
	router.Delete("/gm/tenement", DeleteTenement)
}

//用于将参数转化为切片
func getQueryValues(c *fiber.Ctx, paramName string) []string {
	values := c.Request().URI().QueryArgs().PeekMulti(paramName)
	result := make([]string, len(values))
	for i, v := range values {
		result[i] = string(v)
	}
	return result
}

func DeleteTenement(c *fiber.Ctx) error {
	park := c.Query("park", "")
	tenements := getQueryValues(c, "tenements")
	result := response.NewResult(c)
	GmLog.Info("[天神模式]删除指定园区中的商户", zap.String("park", park), zap.Strings("tenements", tenements))

	err := service.GMService.DeleteTenements(park, tenements)
	if err != nil {
		GmLog.Error("[天神模式]删除指定园区中的商户失败", zap.Error(err))
		return result.Error(500, err.Error())
	}

	return result.Success("指定商户已经删除。")
}
